==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/tr/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> Durumu',
    '<strong>Queue</strong> Status' => '<strong>Kuyruk</strong> Durumu',
    'About HumHub' => 'HumHub Hakkında',
    'Assets' => 'Varlıklar',
    'Background Jobs' => 'Arkaplan İşleri',
    'Base URL' => 'Temel URL',
    'Checking HumHub software prerequisites.' => 'HumHub yazılım önkoşulları denetleniyor.',
    'Current limit is: {currentLimit}' => 'Mevcut limit: {currentLimit}',
    'Database' => 'Veritabanı',
    'Database collation' => 'Veritabanı karşılaştırma',
    'Database driver - {driver}' => 'Veritabanı sürücüsü - {driver}',
    'Database migration results:' => 'Veritabanı taşıma sonuçları:',
    'Delayed' => 'Gecikmiş',
    'Displaying {count} entries per page.' => 'Sayfabaşına görüntülenen girdiler {count}',
    'Done' => 'Tamam',
    'Driver' => 'Sürücü',
    'Dynamic Config' => 'Dinamik Yapılandırma',
    'Error' => 'Hata',
    'Flush entries' => 'Tüm girdileri sil',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub şu anda hata ayıklama modunda. İşlem yaparken devre dışı bırakın!',
    'Info' => 'Bilgi',
    'Install {phpExtension} Extension' => '{phpExtension} Uzantısını yükleyin',
    'Install {phpExtension} Extension for APC Caching' => 'APC Caching için {phpExtension} uzantısını yükleyin',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => 'E-Mail S/MIME desteği için {phpExtension} uzantısını yükleyin',
    'Last run (daily):' => 'Son çalıştırma (günlük):',
    'Last run (hourly):' => 'Son çalıştırma (saatlik):',
    'Licences' => 'Lisanslar',
    'Logging' => 'Günlük',
    'Never' => 'Asla',
    'Optional' => 'Opsiyonel',
    'Other' => 'Diğer',
    'Permissions' => 'İzinler',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Cronjobs ve kuyruk çalışanlarını ayarlamak için lütfen belgelere bakın.',
    'Prerequisites' => 'Gereksinim',
    'Profile Image' => 'Profil resmi',
    'Queue successfully cleared.' => 'Sıra başarıyla temizlendi.',
    'Re-Run tests' => 'Yeniden test et',
    'Reserved' => 'Ayrılmış',
    'Runtime' => 'Çalışma süresi',
    'Search index rebuild in progress.' => 'Arama dizini yeniden oluşturuluyor.',
    'See installation manual for more details.' => 'Daha fazla bilgi için kurulum kılavuzuna bakınız.',
    'Select category..' => 'Kategori seçin..',
    'Settings' => 'Ayarlar',
    'Supported drivers: {drivers}' => 'Desteklenen sürücüler: {drivers}',
    'The current main HumHub database name is ' => 'Geçerli ana HumHub veritabanı adı',
    'There is a new update available! (Latest version: %version%)' => 'Yeni bir güncelleme mevcut! (Son sürüm: %version%)',
    'This HumHub installation is up to date!' => '<strong>HumHub</strong> sürümünüz güncel!',
    'Total {count} entries found.' => 'Toplam bulunan girdiler {count}',
    'Version' => 'Versiyon',
    'Waiting' => 'Bekleme',
    'Warning' => 'Uyarı',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Configuration File' => '',
    'Custom Modules ({modules})' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Search term...' => '',
    'Select day' => '',
    'Select level...' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/tr/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => '<strong>CronJob</strong> Durumu',
    '<strong>Queue</strong> Status' => '<strong>Kuyruk</strong> Durumu',
    'About HumHub' => 'HumHub Hakkında',
    'Assets' => 'Varlıklar',
    'Background Jobs' => 'Arkaplan İşleri',
    'Base URL' => 'Temel URL',
    'Checking HumHub software prerequisites.' => 'HumHub yazılım önkoşulları denetleniyor.',
    'Current limit is: {currentLimit}' => 'Mevcut limit: {currentLimit}',
    'Database' => 'Veritabanı',
    'Database collation' => 'Veritabanı karşılaştırma',
    'Database driver - {driver}' => 'Veritabanı sürücüsü - {driver}',
    'Database migration results:' => 'Veritabanı taşıma sonuçları:',
    'Delayed' => 'Gecikmiş',
    'Displaying {count} entries per page.' => 'Sayfabaşına görüntülenen girdiler {count}',
    'Done' => 'Tamam',
    'Driver' => 'Sürücü',
    'Error' => 'Hata',
    'Flush entries' => 'Tüm girdileri sil',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub şu anda hata ayıklama modunda. İşlem yaparken devre dışı bırakın!',
    'Info' => 'Bilgi',
    'Install {phpExtension} Extension' => '{phpExtension} Uzantısını yükleyin',
    'Install {phpExtension} Extension for APC Caching' => 'APC Caching için {phpExtension} uzantısını yükleyin',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => 'E-Mail S/MIME desteği için {phpExtension} uzantısını yükleyin',
    'Last run (daily):' => 'Son çalıştırma (günlük):',
    'Last run (hourly):' => 'Son çalıştırma (saatlik):',
    'Licences' => 'Lisanslar',
    'Logging' => 'Günlük',
    'Never' => 'Asla',
    'Optional' => 'Opsiyonel',
    'Other' => 'Diğer',
    'Permissions' => 'İzinler',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Cronjobs ve kuyruk çalışanlarını ayarlamak için lütfen belgelere bakın.',
    'Prerequisites' => 'Gereksinim',
    'Profile Image' => 'Profil resmi',
    'Queue successfully cleared.' => 'Sıra başarıyla temizlendi.',
    'Re-Run tests' => 'Yeniden test et',
    'Reserved' => 'Ayrılmış',
    'Runtime' => 'Çalışma süresi',
    'Search index rebuild in progress.' => 'Arama dizini yeniden oluşturuluyor.',
    'See installation manual for more details.' => 'Daha fazla bilgi için kurulum kılavuzuna bakınız.',
    'Select category..' => 'Kategori seçin..',
    'Settings' => 'Ayarlar',
    'Supported drivers: {drivers}' => 'Desteklenen sürücüler: {drivers}',
    'The current main HumHub database name is ' => 'Geçerli ana HumHub veritabanı adı',
    'There is a new update available! (Latest version: %version%)' => 'Yeni bir güncelleme mevcut! (Son sürüm: %version%)',
    'This HumHub installation is up to date!' => '<strong>HumHub</strong> sürümünüz güncel!',
    'Total {count} entries found.' => 'Toplam bulunan girdiler {count}',
    'Version' => 'Versiyon',
    'Waiting' => 'Bekleme',
    'Warning' => 'Uyarı',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Configuration File' => '',
    'Custom Modules ({modules})' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Search term...' => '',
    'Select day' => '',
    'Select level...' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
